package MT::Plugin::MultiPreview;

use strict;
use MT;

use vars qw( $VERSION );
$VERSION = '0.2';

use base qw( MT::Plugin );

###################################### Init Plugin #####################################

my $plugin = new MT::Plugin::MultiPreview({
    id => 'MultiPreview',
    name => 'MultiPreview',
    description => '<MT_TRANS phrase=\'_PLUGIN_DESCRIPTION\'>',
    author_name => 'Shinchi, Takahiro',
    author_link => 'http://www.ark-web.jp/',
    version => $VERSION,
    l10n_class => 'MultiPreview::L10N',
});
MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        'applications' => {
            'cms' => {
                'methods' => {
                    'view_multi_preview' => \&_view_multi_preview,
                },
            },
        },
        widgets => {
            multi_preview => {
                label => 'Multi Preview',
                plugin   => $plugin,
                template => 'multi_preview.mtml',
                handler  => \&_multi_preview_widget,
                set      => 'sidebar',
                singular => 1,
            },
        },
    });
}

sub init_request {
    my $plugin = shift;
    my ( $app ) = @_;
    if ( $app->isa('MT::App::CMS') ) {  
        my $blog = $app->blog;
        if ( defined $blog ) {
            my $plugin_tmpdir = File::Spec->catdir( $plugin->path, 'tmpl' );
            $app->config( 'AltTemplatePath', $plugin_tmpdir );
        }
    }
}

sub _multi_preview_widget {
    my $app = shift;
    my ( $tmpl, $param ) = @_;

    $param->{'entries'} = &_set_target_entries($app, $tmpl, 'entry');
    $param->{'pages'} = &_set_target_entries($app, $tmpl, 'page');
}

sub _set_target_entries {
    my $app = shift;
    my ( $tmpl, $type ) = @_;

    my $class;
    if ( $type eq 'entry' ) {
        $class = 'MT::Entry';
    } elsif ( $type eq 'page' ) {
        $class = 'MT::Page';
    } else {
        return [];
    }

    eval "require $class";
    my @objects = $class->load(
        {
            author_id => $app->user->id,
            status => MT::Entry::HOLD(),
        },
        {
            sort => 'created_on',
            direction => 'descend',
        },
    );

    my @object_info = ();
    for my $object (@objects) {
        my $blog = MT::Blog->load($object->blog_id);
        my $tmp = {
            id => $object->id,
            blog_id => $blog->id,
            blog_name => $blog->name,
            title => $object->title,
            author => $object->author->name,
        };
        push(@object_info, $tmp);
    }

    return \@object_info;
}

sub _view_multi_preview {
    my $app = shift;

    # ץӥ塼
    $app->preview_entry;

    # ץӥ塼˥쥯
    my $preview_dir_url = $app->blog->archive_url;
    $preview_dir_url .= '/' if( $preview_dir_url !~ m/\/$/ );
    $app->redirect($preview_dir_url . $app->preview_object_basename . '.' . $app->blog->file_extension);
}

1;
